.. _runtime:

#############
Runtime Table
#############

.. currentmodule:: fitbenchmarking.results_processing.runtime_table
.. autoclass:: fitbenchmarking.results_processing.runtime_table.RuntimeTable
	       :noindex:
